<template>
  <a-spin :spinning="confirmLoading">
    <j-form-container :disabled="formDisabled">
      <a-form-model ref="form" :model="model" slot="detail" :rules="validatorRules">
        <a-row type="flex" :gutter="16">
          <a-col :span="24">
            <a-form-model-item label="计量单位分类编码" :labelCol="labelCol" :wrapperCol="wrapperCol" prop="code">
              <a-input v-model="model.code" placeholder="请输入计量单位分类编码"></a-input>
            </a-form-model-item>
          </a-col>

          <a-col :span="24">
            <a-form-model-item label="计量单位分类名称" :labelCol="labelCol" :wrapperCol="wrapperCol" prop="name">
              <a-input style="width: 100%" :min="1" v-model="model.name" placeholder="请输入计量单位分类名称"></a-input>
            </a-form-model-item>
          </a-col>

          <a-col :span="24">
            <a-form-model-item label="上级分类" :labelCol="labelCol" :wrapperCol="wrapperCol" prop="pName">
              <a-input style="width: 100%" :min="1" v-model="model.pname" :disabled="true"></a-input>
            </a-form-model-item>
          </a-col>

          <a-col :span="24">
            <a-form-model-item label="备注" :labelCol="labelCol" :wrapperCol="wrapperCol" prop="remark">
              <a-input style="width: 100%" :min="1" v-model="model.remark" placeholder="请输入备注"></a-input>
            </a-form-model-item>
          </a-col>
        </a-row>
        <a-row type="flex" :gutter="16" justify="center">
          <a-col>
            <a-button type="primary" @click="submitForm">保存</a-button>
          </a-col>

<!--          <a-col>
            <a-button type="primary" @click="submitFormAndAdd">保存并新增</a-button>
          </a-col>-->

          <a-col>
            <a-button type="primary" @click="close">取消</a-button>
          </a-col>
        </a-row>
      </a-form-model>
    </j-form-container>
  </a-spin>
</template>

<script>
import { httpAction, getAction } from '@/api/manage'
import { validateDuplicateValue } from '@/utils/util'
import JFormContainer from '@/components/jeecg/JFormContainer'
import JDate from '@/components/jeecg/JDate'
import JDictSelectTag from '@/components/dict/JDictSelectTag'

export default {
  name: 'MomBaseUnitCategoryForm',
  components: {
    JFormContainer,
    JDate,
    JDictSelectTag,
  },
  props: {
    formData: {
      type: Object,
      default: () => {},
      required: false,
    },
    normal: {
      type: Boolean,
      default: false,
      required: false,
    },
    disabled: {
      type: Boolean,
      default: false,
      required: false,
    },
  },
  data() {
    return {
      model: { status: 1 },
      id: '',
      labelCol: {
        xs: { span: 24 },
        sm: { span: 5 },
      },
      wrapperCol: {
        xs: { span: 24 },
        sm: { span: 16 },
      },
      confirmLoading: false,
      url: {
        add: '/base/add',
        delete: '/base/delete',
      },
      validatorRules: {
        code: [{ required: true, message: '请输入计量单位分类编码!' }, { trigger: 'blur' }],
        name: [{ required: true, message: '请输入计量单位分类名称!' }, { trigger: 'blur' }],
      },
      cb: null,
    }
  },
  computed: {
    formDisabled() {
      if (this.normal === false) {
        if (this.formData.disabled === false) {
          return false
        } else {
          return true
        }
      }
      return this.disabled
    },
    disabledId() {
      return this.id ? true : false
    },
    showFlowSubmitButton() {
      if (this.normal === false) {
        if (this.formData.disabled === false) {
          return true
        } else {
          return false
        }
      } else {
        return false
      }
    },
  },
  created() {
    this.showFlowData()
  },
  methods: {
    showAdd(record, { cb }) {
      this.cb = cb
      this.model = record ? Object.assign({}, record) : this.model
      this.id = record ? record.id : ''
      this.model.id = ''
      this.model.code = ''
      this.model.name = ''
      this.model.remark = ''
      this.model.createBy = ''
      this.model.createTime = ''
      this.model.updateBy = ''
      this.model.updateTime = ''
      this.model.pid = record.id
      this.model.pname = record.codeName
      this.visible = true
    },
    show(record, { cb }) {
      this.cb = cb
      this.model = record ? Object.assign({}, record) : this.model
      this.id = record ? record.id : ''
      this.visible = true
    },
    showFlowData() {
      if (this.normal === false) {
        let params = { id: this.formData.dataId }
        getAction(this.url.queryById, params).then((res) => {
          if (res.success) {
            this.edit(res.result)
          }
        })
      }
    },
    //保存按钮触发
    submitForm() {
      const that = this
      // 触发表单验证
      that.$refs.form.validate((valid) => {
        if (valid) {
          that.confirmLoading = true
          let httpurl = this.url.add
          let method = 'post'
          httpAction(httpurl, this.model, method)
            .then((res) => {
              if (res.success) {
                that.$message.success(res.message)
                that.$emit('ok')
              } else {
                that.$message.warning(res.message)
              }
            })
            .finally(() => {
              that.confirmLoading = false
              this.cb(this.id)
              this.cb = null
            })
        } else {
          return false
        }
      })
    },
    //保存并新增按钮触发
    submitFormAndAdd() {
      const that = this
      // 触发表单验证
      that.$refs.form.validate((valid) => {
        if (valid) {
          that.confirmLoading = true
          let httpurl = this.url.add
          let method = 'post'
          httpAction(httpurl, this.model, method)
            .then((res) => {
              if (res.success) {
                that.$message.success(res.message)
              } else {
                that.$message.warning(res.message)
              }
            })
            .finally(() => {
              this.confirmLoading = false
              this.model.id = ''
              this.model.code = ''
              this.model.name = ''
              this.cb(this.id)
            })
        } else {
          return false
        }
      })
    },
    //取消按钮触发
    close() {
      this.$emit('ok')
      this.visible = false
    },
  },
}
</script>
